# myagents

## Quick start

```bash
pip install myagents
```

```python
from myagents import ...
```

## Contributing

```bash
# clone the repo
git clone https://github.com/kanitvural/myagents.git

# install the dev dependencies
make install

# run the tests
make test
```
